﻿using Syncfusion.UI.Xaml.Schedule;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.IO;
using System.Linq;
using System.Runtime.InteropServices.WindowsRuntime;
using Windows.Foundation;
using Windows.Foundation.Collections;
using Windows.UI.Xaml;
using Windows.UI.Xaml.Controls;
using Windows.UI.Xaml.Controls.Primitives;
using Windows.UI.Xaml.Data;
using Windows.UI.Xaml.Input;
using Windows.UI.Xaml.Media;
using Windows.UI.Xaml.Navigation;

// The Blank Page item template is documented at http://go.microsoft.com/fwlink/?LinkId=402352&clcid=0x409

namespace SfSchedule_UWP
{
    /// <summary>
    /// An empty page that can be used on its own or navigated to within a Frame.
    /// </summary>
    public sealed partial class MainPage : Page
    {
        bool disableAppointmentEditor = false;
        private ScheduleAppointmentCollection m_Source = new ScheduleAppointmentCollection();
        public ScheduleAppointmentCollection Source
        {
            get { return m_Source; }
            set { m_Source = value; }
        }
        public MainPage()
        {
            this.InitializeComponent();
            Source = new ScheduleAppointmentCollection
            {
                new CustomAppointment{IsBlockHours=true,Subject="BlockedHours",StartTime=DateTime.Now.Date.AddHours(1),EndTime=DateTime.Now.Date.AddHours(2)},
                new CustomAppointment{IsBlockHours=false,Subject="CheckUp",StartTime=DateTime.Now.Date.AddDays(1).AddHours(1),EndTime=DateTime.Now.Date.AddDays(1).AddHours(8)},
                new CustomAppointment{IsBlockHours=true,Subject="BlockedHours",StartTime=DateTime.Now.Date.AddDays(-1).AddHours(3),EndTime=DateTime.Now.Date.AddDays(-1).AddHours(5)},
                new CustomAppointment{IsBlockHours=false,Subject="CheckUp",StartTime=DateTime.Now.Date.AddDays(-2).AddHours(6),EndTime=DateTime.Now.Date.AddDays(-2).AddHours(10)},
                new CustomAppointment{IsBlockHours=true,Subject="BlockedHours",StartTime=DateTime.Now.Date.AddDays(-3).AddHours(2),EndTime=DateTime.Now.Date.AddDays(-3).AddHours(7)}

            };
            this.DataContext = this;
            this.schedule.ContextMenuOpening += Schedule_ContextMenuOpening;
            this.schedule.AppointmentEditorOpening += Schedule_AppointmentEditorOpening;
            this.schedule.MoveToTime(new TimeSpan(0, 10, 0));
        }

        private void Schedule_AppointmentEditorOpening(object sender, AppointmentEditorOpeningEventArgs e)
        {
           if(disableAppointmentEditor ==true)
            {
                e.Cancel = true;
                disableAppointmentEditor = false;
            }
           
        }

        private void Schedule_ContextMenuOpening(object sender, ContextMenuOpeningEventArgs e)
        {
            foreach (CustomAppointment app in Source)
            {
                if (app.IsBlockHours && app.StartTime <= e.CurrentSelectedDate && app.EndTime > e.CurrentSelectedDate )
                {
                    e.Cancel = true;
                    disableAppointmentEditor = true;

                }
              
            }
        }

 
    }

    public class CustomAppointment : ScheduleAppointment, INotifyPropertyChanged
    {

        private bool isBlockHours;
        public bool IsBlockHours
        {
            get { return isBlockHours; }
            set { isBlockHours = value; OnPropertyChanged("IsBlockHours"); }
        }


        public new event PropertyChangedEventHandler PropertyChanged;

        private void OnPropertyChanged(string propertyName)
        {
            var eventHandler = this.PropertyChanged;
            if (eventHandler != null)
                eventHandler(this, new PropertyChangedEventArgs(propertyName));
        }
    }

    public class OpacityConvertor :IValueConverter
    {
      public object Convert(object value, Type targetType, object parameter, string language)
        {
            var app = value as CustomAppointment;
            if (app.IsBlockHours == true)
                return 0.2;
            else
                return 1;
        }
        public object ConvertBack(object value, Type targetType, object parameter, string language)
        {
            throw new NotImplementedException();
        }
    }
    public class HitTestVisibleConvertor : IValueConverter
    {
        public object Convert(object value, Type targetType, object parameter, string language)
        {
            var app = value as CustomAppointment;
            if (app.IsBlockHours == true)
                return false;
            else
                return true;
        }
        public object ConvertBack(object value, Type targetType, object parameter, string language)
        {
            throw new NotImplementedException();
        }
    }
}
